//
//
//	Customizable Z-Scale Building - rooflet
//	By Stephen Baird
//	Heavily based on "Customizable Modular Building"
// By Steve Medwin
//	(Thanks other Steve!)
//
//	April 2015
//

//	How many wall segments do you want?
number_of_units = 1;
// Include the wall?
show_building = 1; //show the building? 1 for yes, 0 for no
//	Include the corner?
show_corner = 1; //show the corner? 1 for yes, 0 for no

// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
//	CONFIGURATION
// !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!

//
// Basic Options
//

// Number of horizontal windows
horizontal_windows=3; //[1:10]
Ncol=horizontal_windows;
// Number of vertical windows
vertical_windows=1; //[1:5]
Nrow=vertical_windows;

show_door="no"; //[yes,no]
show_windows="yes"; //[yes,no]
show_bricks="no"; //[yes,no]
show_roof="yes"; //[yes,no]
stand_pipe="no";	//[yes,no]

//
// Advanced Options
//

// windows
Xinit=8*1; // Distance from left edge to first window
Yinit=2*1; //5 Distance from bottom to first window row
Xspace=10*1; // Distance from left edge of window to next left edge of window
Yspace=15.5*1; // Distance from bottom of window row to next row
Zbase=4.0*1; // Thickness of wall
Xwin=6.4*1; // (6.4) Width of window
Ywin=12*1; // Height of window
Yheight=5*1; //make double tall first floor
Zwin=2*1; // Depth of windows
Xmuntin=1*1; // Height of window muntin
Ymuntin=Xmuntin;
Zmuntin=0.8*1; // Thickness of window muntin
YwinArc=0.25*1; // Parameter for top of window arc
Xjam=1.0*1; //Width of door jam

Xbase=Xinit*2+Xspace*(Ncol-1)+Xwin; // Width of wall
Ybase=Yinit*2+Yspace*(Nrow-1)+Yheight+2.97; // Height of wall without roof
Xdoor=(Xspace+Xwin)/2-Xwin-Xjam/2;

// roof
Xroof=Xbase;
Yroof=2*1; // Height of roof
Zroof=1*1; // Depth of roof in addition to wall thickness
Droof=1*1; // Size of roof crenelation

// bricks
Xbrick=3*1; // Width of bricks
Ybrick=1*1; // Height of bricks (3:1 ratio)
Zbrick=0.205*1; // Height and depth of brick grout below surface (okay at @ .21,.19)

Num = number_of_units-1;

// !!!!!!!!!!!!!!!!!!!!!!!!!!
// BEGIN PROGRAM
// !!!!!!!!!!!!!!!!!!!!!!!!!!

module rl_walls(Num){
for (i = [0:Num]){
translate([Xbase*i,0,0]) wall();
}
//right wall
rotate([0,90,0]){
translate([4,0,Xbase*(Num+1)+4]){
for (i = [0:Num]){
translate([Xbase*i,0,0]) wall();
	}
}
}
//back wall
rotate([0,180,0]){
translate([-Xbase*(Num+1),0,Xbase*(Num+1)+8]){
if (show_building==1){
for (i = [0:Num]){
translate([Xbase*i,0,0]) wall();
}
}
}
//left wall
rotate([0,90,0]){
translate([-Xbase*(Num+1)-4,0,4]){
for (i = [0:Num]){
translate([Xbase*i,0,0]) wall();
	}
}
}
}}


if (show_building==1){
rl_walls();
}

//Corner
if (show_corner == 1){
rl_corners();
}

//
//	MODULES
//
// facade


module rl_corners(Num){
corner();
rotate([0,90,0]) translate([4,0,Xbase*(Num+1)+4])corner();
rotate([0,180,0]) translate([-Xbase*(Num+1),0,Xbase*(Num+1)+8]) corner();
rotate([0,-90,0])translate([-Xbase*(Num+1)-4,0,4]) corner();
}


//CORNER!
module corner(){
difference(){
	rotate([-90,0,0]) translate([0,4,0]) cylinder(Ybase+2,4,4); //corner itself
	translate([0,-1,-9]) cube([4.5,Ybase+4,10]); //cut off unneded side
	translate([-4.5,-1,-8.5]) cube([10,Ybase+4,4.5]); //cut off unneded back
//connection slot
translate([-1.5,0,-Zbase]) cube([2,Ybase+Yroof+.5,2]);
}
//connection tab
translate([-2,0,-Zbase-2]) cube([2,Ybase+Yroof,2]);

//roof continuation
difference(){
rotate([90,0,180]){
translate([0,-4,Ybase+.5]){
rotate_extrude (convexity = 10){
polygon(points=[[3.6,-.5],[3.6,1.5],[5.5,1.5],[5.5,1]], paths=[[0,1,2,3]]);
}}}
	translate([0,-1,-11]) cube([6.5,Ybase+4,14]); //cut off unneded side
	translate([-5.5,-1,-9.5]) cube([12,Ybase+4,5.5]); //cut off unneded back
}
}

module facade(){
	translate([0,0,-Zbase]) cube([Xbase,Ybase+Yroof,Zbase]);
}

//	bricks
module bricks(){
	for (i=[0:Ybase/Ybrick]){
		translate([0,i*Ybrick-Zbrick,-Zbrick]) cube([Xbase,Zbrick,Zbrick]); // on front
//		translate([0,i*Ybrick-Zbrick,-Zbase]) cube([Zbrick,Zbrick,Zbase]); // on left edge
//		translate([Xbase-Zbrick,i*Ybrick-Zbrick,-Zbase]) cube([Zbrick,Zbrick,Zbase]); // on right edge	
		// add vertical lines for bricks
		for (j=[0:Xbase/Xbrick]){
			if (i/2==floor(i/2)) {
				translate([0,i*Ybrick,-Zbrick]) translate([j*Xbrick,0,0]) cube([Zbrick,Ybrick,Zbrick]);
				}
			else {
				translate([0,i*Ybrick,-Zbrick]) translate([j*Xbrick+Xbrick/2,0,0]) cube([Zbrick,Ybrick,Zbrick]);
				}
		}
	}
}


// roof
module roof(){
	Dcount=((Xbase-Xinit*2)/(Droof*2));
	XbaseP=(Dcount+1)*Droof*2-Droof;
	XinitP=(Xbase-XbaseP)/2;
	difference(){
	hull(){		
	translate ([0,Ybase+1.5,-Zbase]) cube([Xroof,Yroof-1.5,Zbase+Zroof+.5]);
	translate ([0,Ybase,-Zbase]) cube([Xroof,Yroof-.5,Zbase+Zroof-1.5]);
	}
	translate([Xbase-1.5,0,-Zbase]) cube([2,Ybase+Yroof,2]);
	}
difference(){
for(i = [0:3]){
hull(){
translate ([Xinit-1.25+Xwin*i*1.5,Ywin+1,-Zwin-1.5]) ellipticalCylinder(.65*Xwin,Ywin*YwinArc,Zwin+2.5);
translate ([Xinit-1.25+Xwin*i*1.5,Ywin+1,-Zwin-1.5]) scale([1.1,1.1,.75]) ellipticalCylinder(.65*Xwin,Ywin*YwinArc,Zwin+2.5);
}
}
translate([Xbase,1,-Zbase]) cube([2,Ybase+Yroof,2]);
translate([0,Ybase+1,-5]) cube([Xbase, 5, 10]);
}
}


// door
module door(){
	translate ([Xinit+Xspace*(floor(Ncol/2)),Yinit,-Zwin-2.1]) cube([Xwin,Ywin,Zwin+2.5]);  // add extra depth to improve Customizer rendering
	translate ([Xinit+Xspace*(floor(Ncol/2))+Xwin/2,Yinit+Ywin,-Zwin-2.1]) ellipticalCylinder(Xwin/2,Ywin*YwinArc,Zwin+2.5);
	translate ([Xinit+Xspace*(floor(Ncol/2)),0,-Zwin+Zmuntin]) cube([Xwin,Yinit,Zwin]); // bottom of door
	if (Ncol/2==floor(Ncol/2)) {  // then Ncol is even so make a double door
		translate ([Xinit+Xspace*(Ncol/2-1),Yinit,-Zwin-2]) cube([Xwin,Ywin,Zwin+2]);
 		translate ([Xinit+Xspace*(Ncol/2-1),0,-Zwin+Zmuntin]) cube([Xwin+Xspace,Yinit+Ywin+Ymuntin,Zwin]);
		translate ([Xinit+Xspace*(Ncol/2-1)+Xwin+Xdoor,Yinit,-Zwin]) cube([Xjam,Ywin/2-Ymuntin/2,Zwin]);
		translate ([Xinit+Xspace*(Ncol/2-1)+Xwin+Xdoor,Yinit+Ywin/2+Ymuntin/2,-Zwin]) cube([Xjam,Ywin/2-Ymuntin/2,Zwin]);
		translate ([Xinit+Xspace*(Ncol/2)-Xdoor-Xjam/2,Yinit+Ywin+Ymuntin,-Zwin+Zmuntin]) ellipticalCylinder((Xwin+Xspace)/2,Ywin*YwinArc*1.2,Zwin);
		}
	}




// building
module building(){
	translate([-1.5,0,-Zbase]) cube([.2+.5*Xinit,Ybase+Yroof,.3+.2+Zbase/2]); 
difference(){
		facade();
//bottom connection slot
hull(){
	translate([-1+1.5*Xspace,0,-Zbase]) cube([3*(.2+.5*Xinit)+3,1,.3+Zbase/2]);
	translate([-1+1.5*Xspace,1.9,-Zbase]) cube([3*(.2+.5*Xinit)+3,.1,.1]);
}
//right connection slot
translate([Xbase-1.5,0,-Zbase]) cube([2,Ybase+Yroof,2]);
	}
	

	//	subtract windows
		if (show_door == "yes"){
		for (i=[0:Nrow-1]){
			for (j=[0,Ncol-1]){
				if (show_windows=="yes") {
					window(Xinit+j*Xspace,Yheight*.4+i*Yspace,0);
					}
			}
		}
		}

		if (show_door == "no"){
		for (i=[0:Nrow-1]){
			for (j=[0:Ncol-1]){
				if (show_windows=="yes") {
					window(Xinit+j*Xspace,Yheight*.4+i*Yspace,0);
					}
			}
		}
		}
	if (show_bricks=="yes") { 
			bricks(); 
			}
	}




//=============================================
//			THING I ADDED THAT NEED TO BE PARAMETRIZED
//=============================================


module standpipe(){
scale([1.1,1,1.1]){
//main standpipe
rotate([270,0,0]) translate([2,-.35,18]) cylinder(8,.5,.5);


//middle anchor
hull(){
rotate([270,0,0]) translate([2,-.35,22]) cylinder(.5,.75,.75);
rotate([270,0,0]) translate([2,-.35,21.875]) cylinder(.75,.5,.5);
}

//horizontal standpipe
hull(){
rotate([270,0,0]) translate([2,-.35,18]) cylinder(1,.5,.5);
translate([2,18,.35]) sphere(.5);
}
translate([2,18,-.1]) cylinder(.3,.7,.7);
}}



//
// ASSEMBLE BUILDING
//
module wall(){
difference(){
	building();
	if (show_door=="yes") {
		door();
		}
	}

if (show_roof=="yes") {
	roof();
	}

if (stand_pipe =="yes")	{
	standpipe();
	}

// add muntins
if (show_door =="yes"){
for (i=[0:Nrow-1]){
		for (j=[0,Ncol-1]){
			muntins(Xinit+j*Xspace,Yheight*.4+i*Yspace,0);
		}
	}}
if (show_door =="no"){
for (i=[0:Nrow-1]){
		for (j=[0:Ncol-1]){
			muntins(Xinit+j*Xspace,Yheight*.4+i*Yspace,0);
		}
	}}

}

$fn=36*1;
use <MCAD\shapes.scad>